<?php

namespace Drupal\social_event_invite_flow\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\virtual_event_bbb\VirtualEventBBB;
use BigBlueButton\Parameters\JoinMeetingParameters;
use Drupal\Core\Url;
use Drupal\Core\Routing\TrustedRedirectResponse;

/**
 * Provides a Social event invite flow form.
 */
class JoinVirtualEventAsGuest extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_event_invite_flow_join_virtual_event_as_guest';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $nid = NULL) {


 

    $form['#attributes'] = [
      'class' => ['visually-hidden']
    ];


    $form['fieldset'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Join Meeting now'),
      '#collapsed' => FALSE,
    ];

    $form['fieldset']['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
    ];

    $form['fieldset']['event_id'] = [
      '#type' => 'hidden',
      '#value' => $nid,
    ];

    $form['fieldset']['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name')
    ];

    $form['fieldset']['actions'] = [
      '#type' => 'actions',
    ];
    $form['fieldset']['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('JOIN MEETING'),
      '#attributes' => [
        'class' => [
          'btn-accent',
          'button',
          'btn',
          'btn-lg',
          'waves-effect',
          'waves-btn',
          'waves-light',
        ]
      ]
    ];

/** @var \Drupal\data_policy\DataPolicyConsentManagerInterface $data_policy_manager */
$data_policy_manager = \Drupal::service('data_policy.manager');

if (!$data_policy_manager->isDataPolicy()) {
  return;
}

if (\Drupal::routeMatch()->getRouteName() === 'user.admin_create') {
  return;
}

$data_policy_manager->addCheckbox($form);


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $event_id = $form_state->getValue('event_id');
    $name = $form_state->getValue('name');

    $node = \Drupal::entityTypeManager()->getStorage('node')->load($event_id);



    
    $BBBKeyPluginManager = \Drupal::service('plugin.manager.bbbkey_plugin');
    $virtualEventsCommon = \Drupal::service('virtual_events.common');
    $event_id = $node->bundle() . '_' . $node->uuid();


    $event = $virtualEventsCommon->getEventById($event_id);

    if ($event) {
      // Check if meeting is not active,
      // recreate it before showing the join url
      $event = $event->reCreate();

      $entity = $event->getEntity();
      $enabled_event_source = $event->getEnabledSourceKey();
      
      $event_config = $event->getVirtualEventsConfig($enabled_event_source);
      $source_config = $event_config->getSourceConfig($enabled_event_source);
     
      $source_data = $event->getSourceData();
      $eventSourcePlugin = $event->getEventSourcePlugin();
      if(!isset($source_config["data"]["key_type"])) {
        $error_message = $this->t("Couldn't create meeting! please contact system administrator.");      
      }

      $keyPlugin = $BBBKeyPluginManager->createInstance($source_config["data"]["key_type"]);
      $keys = $keyPlugin->getKeys($source_config);

      $apiUrl = $keys["url"];
      $secretKey = $keys["secretKey"];
      $bbb = new VirtualEventBBB($secretKey, $apiUrl);

      // Check access for current entity, if user can update
      // then we can consider the user as moderator,
      // otherwise we consider the user as normal attendee.
      $joinMeetingParams = new JoinMeetingParameters($event->id(), $name, $source_data["settings"]["attendeePW"]);
      $joinMeetingParams->setRedirect(TRUE);

      $joinMeetingUrl = $bbb->getJoinMeetingURL($joinMeetingParams);
      $form_state->setResponse(new TrustedRedirectResponse($joinMeetingUrl));


      
    }

  }

}
